@@ -44,9 +44,10 @@
 #'          the labels which are added are Y1, ...Yp.
 #'      }
 #'
-#' @param conflev confidence interval for the horizontal bands. It can be a vector of
-#'  different confidence level values, e.g. c(0.95, 0.99, 0.999).
-#'  The confidence interval is based on the chi^2 distribution.
+#' @param conflev Confidence level which is used to declare units as outliers (scalar).
+#'  Usually \code{conflev=0.95}, \code{conflev=0.975} or \code{conflev=0.99} (individual alpha)
+#'  \code{conflev=1-0.05/n}, \code{conflev=1-0.025/n} or \code{conflev=1-0.01/n} (simultaneous alpha).
+#'  Default value is \code{convlev=0.975}.
 #'
 #' @param nocheck It controls whether to perform checks on matrix Y. If \code{nocheck=TRUE}, no check is performed.
 
@@ -167,6 +168,8 @@ smult <- function(x, monitoring = FALSE, plot=FALSE, bdp, nsamp,
         control$nsamp <- nsamp
 
     control$nocheck <- ifelse(nocheck, 1, 0)
+    if(length(conflev) != 1)
+        stop("Argument 'conflev' must be a scalar!")
     control$conflev <- conflev
 
     outclass <- if(monitoring) "smulteda" else "smult"
