@@ -2,7 +2,7 @@
 ##  VT::12.12.2018
 ##
 ##
-##  roxygen2::roxygenise("C:/projects/statproj/R/fsdaR")
+##  roxygen2::roxygenise("C:/projects/statproj/R/fsdaR", load_code=roxygen2:::load_installed)
 ##
 #'  Computes trimmed clustering with scatter restrictions
 #'
@@ -38,7 +38,7 @@
 #'  traditional model based or mixture clustering (mclust): see for example the
 #'  Matlab function \code{gmdistribution}.
 #'
-#'  More in detail, if \code{0 < alpha < 1} clustering is based on \code{h = fix(n * (1-alpha))}
+#'  More in detail, if \code{0 < alpha < 1} clustering is based on \code{h = floor(n * (1-alpha))}
 #'  observations, else if alpha is an integer greater than 1 clustering is based on \code{h = n - floor(alpha)}.
 #'  If \code{monitoring=TRUE}, \code{alpha} is a vector which specifies the values of
 #'  trimming levels which have to be considered - contains decresing elements which
@@ -195,6 +195,7 @@
 #' @param msg  Controls whether to display or not messages on the screen If \code{msg==TRUE} (default)
 #'  messages are displayed on the screen. If \code{msg=2}, detailed messages are displayed,
 #'  for example the information at iteration level.
+#'
 #' @param nocheck Check input arguments. If \code{nocheck=TRUE} no check is performed
 #'  on matrix \code{X}. The default \code{nocheck=FALSE}.
 #'
@@ -210,6 +211,16 @@
 #' Remark 2 - option \code{startv1} is used just if \code{nsamp} is a scalar
 #'  (see for more details the help associated with \code{nsamp}).
 #'
+#'
+#' @param RandNumbForNini pre-extracted random numbers to initialize proportions.
+#'  Matrix of size k-by-nrow(nsamp) containing the random numbers which
+#'  are used to initialize the proportions of the groups. This option is effective just if
+#'  \code{nsamp} is a matrix which contains pre-extracted subsamples. The purpose of this
+#'  option is to enable to user to replicate the results in case routine \code{tclustreg*()}
+#'  is called using a parfor instruction (as it happens for example in routine IC, where
+#'  \code{tclustreg()} is called through a parfor for different values of the restriction factor).
+#'  The default is that \code{RandNumbForNini} is empty - then uniform random numbers are used.
+#'
 #' @param restrtype Type of restriction to be applied on the cluster scatter matrices.
 #'  Valid values are \code{'eigen'} (default), or \code{'deter'}.
 #'  \code{"eigen"} implies restriction on the eigenvalues while \code{"deter"}
@@ -245,7 +256,7 @@
 #' @references
 #'      Garcia-Escudero, L.A., Gordaliza, A., Matran, C. and Mayo-Iscar, A. (2008).
 #'      A General Trimming Approach to Robust Cluster Analysis. Annals of Statistics,
-#'      Vol. 36, 1324-1345. [Technical Report available at: \url{http://www.eio.uva.es/inves/grupos/representaciones/trTCLUST.pdf}]
+#'      Vol. 36, 1324-1345. \doi{10.1214/07-AOS515}.
 #'
 #' @examples
 #'  \dontrun{
@@ -282,6 +293,33 @@
 #'  ##  Filled contour plots with additional options: contourf plot with autumn colormap
 #'  plots <- list(type="contourf", cmap="autumn")
 #'  out <- tclustfsda(geyser2, k=3, alpha=0.1, restrfactor=10000, plot=plots)
+
+#'  ##  Filled contour plots with additional options: contourf plot with a named colormap.
+#'  ##  Here we define four MATLAB-like colormaps, but the user can define anything else,
+#'  ##  presented by a matrix with three columns which are the RGB triplets.
+#'
+#'  summer <- as.matrix(data.frame(x1=seq(from=0, to=1, length=65),
+#'                                 x2=seq(from=0.5, to=1, length=65),
+#'                                 x3=rep(0.4, 65)))
+#'  spring <- as.matrix(data.frame(x1=rep(1, 65),
+#'                                 x2=seq(from=0, to=1, length=65),
+#'                                 x3=seq(from=1, to=0, length=65)))
+#'  winter <- as.matrix(data.frame(x1=rep(0, 65),
+#'                                 x2=seq(from=0, to=1, length=65),
+#'                                 x3=seq(from=1, to=0, length=65)))
+#'  autumn <- as.matrix(data.frame(x1=rep(1, 65),
+#'                                 x2=seq(from=0, to=1, length=65),
+#'                                 x3=rep(0, 65)))
+#'
+#'  out <- tclustfsda(geyser2, k=3, alpha=0.1, restrfactor=10000,
+#'        plot=list(type="contourf", cmap=autumn))
+#'  out <- tclustfsda(geyser2, k=3, alpha=0.1, restrfactor=10000,
+#'        plot=list(type="contourf", cmap=winter))
+#'  out <- tclustfsda(geyser2, k=3, alpha=0.1, restrfactor=10000,
+#'        plot=list(type="contourf", cmap=spring))
+#'  out <- tclustfsda(geyser2, k=3, alpha=0.1, restrfactor=10000,
+#'        plot=list(type="contourf", cmap=summer))
+#'
 #'
 #'  ##  We compare the output using three different values of restriction factor
 #'  ##      nsamp is the number of subsamples which will be extracted
@@ -402,7 +440,7 @@
 
 tclustfsda <- function(x, k, alpha, restrfactor=12, monitoring=FALSE, plot=FALSE,
         nsamp, refsteps=15, reftol=10e-14, equalweights=FALSE, mixt=0, msg=TRUE, nocheck=FALSE,
-        startv1=1, restrtype= c("eigen", "deter"),
+        startv1=1, RandNumbForNini, restrtype= c("eigen", "deter"),
         UnitsSameGroup, numpool, cleanpool,
         trace=FALSE, ...)
 {
@@ -460,12 +498,23 @@ tclustfsda <- function(x, k, alpha, restrfactor=12, monitoring=FALSE, plot=FALSE
             else
                 stop("Invalid parameter 'plot'. If it is a list, it should contain one or more of the following: ",  paste0(cx, collapse=","))
         }
+
+        ##  VT::30.07.2021 - fixed an issue with colormaps - check that the supploed argument plots$cmap is a matrix with three columns
+        if("cmap" %in% names(xplots))
+        {
+            xplots$cmap <- if(is.data.frame(xplots$cmap)) data.matrix(xplots$cmap) else xplots$cmap
+            if(!is.numeric(xplots$cmap) || !is.matrix(xplots$cmap) || ncol(xplots$cmap) != 3)
+                stop("'plot$cmap' must be a three-column matrix of values in the range [0,1] where each row is an RGB triplet that defines one color!")
+        }
     }else
         stop("Invalid parameter 'plot'. Should be TRUE/FALSE or 0, 1 or character name of a plot or a list with graphical parameters")
 
     control$plots <- xplots
-    if(!missing(nsamp))
+    if(!missing(nsamp)){
         control$nsamp <- nsamp
+        if(is.matrix(nsamp) && !missing(RandNumbForNini))
+            control$RandNumbForNini <- RandNumbForNini
+    }
     control$refsteps <- refsteps
     control$reftol <- reftol
     control$equalweights <- equalweights
@@ -500,6 +549,7 @@ tclustfsda <- function(x, k, alpha, restrfactor=12, monitoring=FALSE, plot=FALSE
         stop("Invalid parameter 'nocheck'. Should be TRUE/FALSE or 0, 1.")
     control$nocheck <- xtemp
     control$startv1 <- startv1
+
     control$restrtype <- match.arg(restrtype)
 
     outclass <- if(monitoring) "tclusteda" else "tclustfsda"
@@ -623,10 +673,17 @@ tclustfsda <- function(x, k, alpha, restrfactor=12, monitoring=FALSE, plot=FALSE
         alphas <- paste0("alpha_", alpha)
 
         MU = .jevalArray(arr$get("MU", as.integer(1)), "[[D", simplify = TRUE)
+
+        ## VT::27.07.2021 - if alpha is a single number, the array MU will be two-dimensional,
+        ##  not three-dimensional as expected by the following setting of dimnames. Change it
+        ##  to trhee-dimensional array, with the third dimension having just one element.
+        if(length(alpha) == 1)
+             MU <- array(MU, c(dim(MU), 1))
+
         dimnames(MU) <- list(paste0("C", 1:k), cols, alphas)
 
         ## Convert a cell array with the length of alpha to a list. Each cell contains
-        ##  a 3D-array with dimension pxpxk
+        ##  a 3D-array with dimension p x p x k
         SIGMA = cell2list(.jevalArray(arr$get("SIGMA", as.integer(1)), "[[D", simplify = TRUE))
         names(SIGMA) <- alphas
         for(i in 1:length(SIGMA))
@@ -635,8 +692,11 @@ tclustfsda <- function(x, k, alpha, restrfactor=12, monitoring=FALSE, plot=FALSE
         IDX = as.matrix(.jevalArray(arr$get("IDX", as.integer(1)), "[[D", simplify = TRUE))
         dimnames(IDX) <- list(rows, paste0("alpha_", alpha))
 
+        ## VT::27.07.2021 - if alpha is a single number, the matrix Amon contains 0 rows (i.e. length(alpha)-1).
+        ##  Actually the returned matrix is also with 0 columns. Therefore do not set the dimnames.
         Amon = as.matrix(.jevalArray(arr$get("Amon", as.integer(1)), "[[D", simplify = TRUE))
-        dimnames(Amon) <- list(1:nrow(Amon), c("alpha", "ARI", "dist_centers", "dist_covs"))
+        if(nrow(Amon)[1] > 0)
+            dimnames(Amon) <- list(1:nrow(Amon), c("alpha", "ARI", "dist_centers", "dist_covs"))
 
         Y <- if(as.integer(arr$hasField("Y", as.integer(1))) != 1) NULL
                     else as.matrix(.jevalArray(arr$get("Y", as.integer(1)), "[[D", simplify = TRUE))
